@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use parent qw(Alien::Base);
 
-our $VERSION = '0.001_001';
+our $VERSION = '0.000001';
 $VERSION = eval $VERSION;
 
 1;
@@ -34,7 +34,7 @@ Alien::Chipmunk - Alien package for the Chipmunk Physics library
             # ...
         },
         extra_compiler_flags => $alien->cflags,
-        extra_linker_flags   => $alien->libs,
+        extra_linker_flags   => $alien->libs . ' -lm',
     );
 
     $builder->create_build_script();
@@ -61,15 +61,13 @@ L<Chipmunk>
 
 =back
 
-=head1 AUTHORS
+=head1 AUTHOR
 
-Jeffrey T. Palmer E<lt>jtpalmer@cpan.orgE<gt>
-
-Graham Ollis E<lt>plicease@cpan.orgE<gt>
+Jeffrey T. Palmer, E<lt>jtpalmer@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Jeffrey T. Palmer.
+This software is Copyright (c) 2012 by Jeffrey T. Palmer.
 
 This is free software, licensed under:
 
